@@ -6,11 +6,13 @@ import re
 import traceback
 
 import requests
+from requests.adapters import HTTPAdapter
 
 from datetime import datetime
 from urllib.parse import urljoin, urlsplit, urlunsplit, SplitResult
 
 from opentracing_utils import trace, extract_span_from_kwargs
+from urllib3 import Retry
 
 from zmon_cli import __version__
 from zmon_cli.config import DEFAULT_TIMEOUT
@@ -41,6 +43,7 @@ CHECK_DEF_VIEW_URL = '#/check-definitions/view/'
 DASHBOARD_VIEW_URL = '#/dashboards/views/'
 GRAFANA_DASHBOARD_URL = 'visualization/dashboard/'
 TOKEN_LOGIN_URL = 'tv/'
+BACKOFF_FACTOR = 0.3
 
 logger = logging.getLogger(__name__)
 
@@ -123,8 +126,18 @@ class Zmon:
     """
 
     def __init__(
-            self, url, token=None, username=None, password=None, timeout=DEFAULT_TIMEOUT, verify=True,
-            user_agent=ZMON_USER_AGENT):
+        self,
+        url,
+        token=None,
+        username=None,
+        password=None,
+        timeout=DEFAULT_TIMEOUT,
+        verify=True,
+        user_agent=ZMON_USER_AGENT,
+        retry_count=None,
+        *args,
+        **kwargs,
+    ):
         """Initialize ZMON client."""
         self.timeout = timeout
 
@@ -133,7 +146,16 @@ class Zmon:
         self.url = urljoin(self.base_url, self._join_path(['api', API_VERSION, '']))
 
         self._session = requests.Session()
-
+        if retry_count:
+            retry = Retry(
+                total=retry_count,
+                read=retry_count,
+                connect=retry_count,
+                backoff_factor=BACKOFF_FACTOR,
+            )
+            adapter = HTTPAdapter(max_retries=retry)
+            self._session.mount('http://', adapter)
+            self._session.mount('https://', adapter)
         self._timeout = timeout
         self.user_agent = user_agent
 
