@@ -4,7 +4,13 @@ import click
 
 from clickclick import AliasedGroup, Action, ok
 
-from zmon_cli.cmds.command import cli, get_client, yaml_output_option, pretty_json, output_option
+from zmon_cli.cmds.command import (
+    cli,
+    get_client,
+    yaml_output_option,
+    pretty_json,
+    output_option,
+)
 from zmon_cli.output import dump_yaml, Output, render_checks
 from zmon_cli.client import ZmonArgumentError
 
