@@ -58,10 +58,6 @@ def set_config_file(config_file, default_url):
 
     data = {'url': url}
 
-    if click.confirm('Is your ZMON using GitHub for authentication?'):
-        token = click.prompt('Your personal access token (optional, only needed for GitHub auth)')
-        data['token'] = token
-
     fn = os.path.expanduser(config_file)
     with Action('Writing configuration to {}..'.format(fn)):
         with open(fn, 'w') as fd:
